@@ -123,6 +123,13 @@ start of '%s=%s', using it in the middle is not allowed."""
                 % (candidate, arg_name, value)
             )
 
+        if candidate == value:
+            Tracing.options_logger.sysexit(
+                """Cannot use general system folder %s, may only be the \
+start of '%s=%s', using that alone is not allowed."""
+                % (candidate, arg_name, value)
+            )
+
 
 def _checkOnefileTargetSpec():
     checkPathSpec(options.onefile_tempdir_spec, arg_name="--onefile-tempdir-spec")
@@ -1722,7 +1729,7 @@ def _getPythonFlags():
             for part in parts.split(","):
                 if part in ("-S", "nosite", "no_site"):
                     _python_flags.add("no_site")
-                elif part in ("site"):
+                elif part in ("site",):
                     if "no_site" in _python_flags:
                         _python_flags.remove("no_site")
                 elif part in (
