@@ -31,17 +31,30 @@ from nuitka.build.SconsInterface import (
     runScons,
     setCommonSconsOptions,
 )
-from nuitka.Options import getOnefileTempDirSpec, isOnefileTempDirMode
+from nuitka.Options import (
+    getOnefileChildGraceTime,
+    getOnefileTempDirSpec,
+    isOnefileTempDirMode,
+)
 from nuitka.OutputDirectories import getResultFullpath
 from nuitka.plugins.Plugins import Plugins
 from nuitka.PostProcessing import executePostProcessingResources
-from nuitka.PythonVersions import python_version
+from nuitka.PythonVersions import (
+    getZstandardSupportingVersions,
+    python_version,
+)
 from nuitka.Tracing import onefile_logger, postprocessing_logger
 from nuitka.utils.Execution import withEnvironmentVarsOverridden
-from nuitka.utils.FileOperations import areSamePaths, removeDirectory
+from nuitka.utils.FileOperations import (
+    areSamePaths,
+    getExternalUsePath,
+    getFileContents,
+    removeDirectory,
+)
 from nuitka.utils.InstalledPythons import findInstalledPython
 from nuitka.utils.Signing import addMacOSCodeSignature
-from nuitka.utils.Utils import getArchitecture, isMacOS, isWin32Windows
+from nuitka.utils.Utils import isMacOS, isWin32OrPosixWindows, isWin32Windows
+from nuitka.utils.WindowsResources import RT_RCDATA, addResourceToFile
 
 
 def packDistFolderToOnefile(dist_dir):
@@ -54,7 +67,7 @@ def packDistFolderToOnefile(dist_dir):
     Plugins.onOnefileFinished(onefile_output_filename)
 
 
-def _runOnefileScons(quiet, onefile_compression):
+def _runOnefileScons(onefile_compression):
     source_dir = OutputDirectories.getSourceDirectoryPath(onefile=True)
 
     # Let plugins do their thing for onefile mode too.
@@ -67,8 +80,6 @@ def _runOnefileScons(quiet, onefile_compression):
         "debug_mode": asBoolStr(Options.is_debug),
         "experimental": ",".join(Options.getExperimentalIndications()),
         "trace_mode": asBoolStr(Options.shallTraceExecution()),
-        "target_arch": getArchitecture(),
-        "python_prefix": sys.prefix,
         "nuitka_src": getSconsDataPath(),
         "compiled_exe": OutputDirectories.getResultFullpath(onefile=False),
         "onefile_splash_screen": asBoolStr(
@@ -76,22 +87,19 @@ def _runOnefileScons(quiet, onefile_compression):
         ),
     }
 
-    if Options.isClang():
-        options["clang_mode"] = "true"
-
     env_values = setCommonSconsOptions(options)
 
     env_values["_NUITKA_ONEFILE_TEMP_SPEC"] = getOnefileTempDirSpec()
     env_values["_NUITKA_ONEFILE_TEMP_BOOL"] = "1" if isOnefileTempDirMode() else "0"
     env_values["_NUITKA_ONEFILE_COMPRESSION_BOOL"] = "1" if onefile_compression else "0"
     env_values["_NUITKA_ONEFILE_BUILD_BOOL"] = "1" if onefile_compression else "0"
+    env_values["_NUITKA_ONEFILE_CHILD_GRACE_TIME_INT"] = str(getOnefileChildGraceTime())
 
     # Allow plugins to build definitions.
     env_values.update(Plugins.getBuildDefinitions())
 
     result = runScons(
         options=options,
-        quiet=quiet,
         env_values=env_values,
         scons_filename="Onefile.scons",
     )
@@ -100,20 +108,10 @@ def _runOnefileScons(quiet, onefile_compression):
     if not result:
         onefile_logger.sysexit("Error, onefile bootstrap binary build failed.")
 
-    if Options.isRemoveBuildDir():
-        onefile_logger.info("Removing onefile build directory '%s'." % source_dir)
-
-        removeDirectory(path=source_dir, ignore_errors=False)
-        assert not os.path.exists(source_dir)
-    else:
-        onefile_logger.info("Keeping onefile build directory '%s'." % source_dir)
-
 
 def getCompressorPython():
-    zstandard_supported_pythons = ("3.5", "3.6", "3.7", "3.8", "3.9", "3.10")
-
     compressor_python = findInstalledPython(
-        python_versions=zstandard_supported_pythons,
+        python_versions=getZstandardSupportingVersions(),
         module_name="zstandard",
         module_version="0.15",
     )
@@ -135,6 +133,7 @@ def runOnefileCompressor(
     compressor_python, dist_dir, onefile_output_filename, start_binary
 ):
     file_checksums = not isOnefileTempDirMode()
+    win_path_sep = isWin32OrPosixWindows()
 
     if compressor_python is None or areSamePaths(
         compressor_python.getPythonExe(), sys.executable
@@ -149,6 +148,7 @@ def runOnefileCompressor(
             start_binary=start_binary,
             expect_compression=compressor_python is not None,
             file_checksums=file_checksums,
+            win_path_sep=win_path_sep,
         )
     else:
         onefile_compressor_path = os.path.normpath(
@@ -174,9 +174,10 @@ def runOnefileCompressor(
                     compressor_python.getPythonExe(),
                     onefile_compressor_path,
                     dist_dir,
-                    onefile_output_filename,
+                    getExternalUsePath(onefile_output_filename, only_dirname=True),
                     start_binary,
                     str(file_checksums),
+                    str(win_path_sep),
                 ],
                 shell=False,
             )
@@ -193,6 +194,9 @@ def packDistFolderToOnefileBootstrap(onefile_output_filename, dist_dir):
     source_dir = OutputDirectories.getSourceDirectoryPath(onefile=True)
     cleanSconsDirectory(source_dir)
 
+    # Used only in some configurations
+    onefile_payload_filename = os.path.join(source_dir, "__payload.bin")
+
     # Now need to append to payload it, potentially compressing it.
     compressor_python = getCompressorPython()
 
@@ -204,13 +208,12 @@ def packDistFolderToOnefileBootstrap(onefile_output_filename, dist_dir):
         runOnefileCompressor(
             compressor_python=compressor_python,
             dist_dir=dist_dir,
-            onefile_output_filename=os.path.join(source_dir, "__payload.bin"),
+            onefile_output_filename=onefile_payload_filename,
             start_binary=getResultFullpath(onefile=False),
         )
 
     # Create the bootstrap binary for unpacking.
     _runOnefileScons(
-        quiet=not Options.isShowScons(),
         onefile_compression=compressor_python is not None,
     )
 
@@ -226,6 +229,28 @@ def packDistFolderToOnefileBootstrap(onefile_output_filename, dist_dir):
         runOnefileCompressor(
             compressor_python=compressor_python,
             dist_dir=dist_dir,
-            onefile_output_filename=onefile_output_filename,
+            onefile_output_filename=(
+                onefile_payload_filename
+                if isWin32Windows()
+                else onefile_output_filename
+            ),
             start_binary=getResultFullpath(onefile=False),
         )
+
+        if isWin32Windows():
+            addResourceToFile(
+                target_filename=onefile_output_filename,
+                data=getFileContents(onefile_payload_filename, mode="rb"),
+                resource_kind=RT_RCDATA,
+                lang_id=0,
+                res_name=27,
+                logger=postprocessing_logger,
+            )
+
+    if Options.isRemoveBuildDir():
+        onefile_logger.info("Removing onefile build directory '%s'." % source_dir)
+
+        removeDirectory(path=source_dir, ignore_errors=False)
+        assert not os.path.exists(source_dir)
+    else:
+        onefile_logger.info("Keeping onefile build directory '%s'." % source_dir)
