@@ -45,15 +45,21 @@ import zipfile
 
 from nuitka import Options, SourceCodeReferences
 from nuitka.__past__ import iter_modules
+from nuitka.containers.Namedtuples import makeNamedtupleClass
 from nuitka.containers.OrderedSets import OrderedSet
 from nuitka.importing import StandardLibrary
 from nuitka.plugins.Plugins import Plugins
+from nuitka.PythonFlavors import isNuitkaPython
 from nuitka.PythonVersions import python_version
 from nuitka.Tracing import my_print, recursion_logger
+from nuitka.tree.ReformulationMultidist import locateMultidistModule
 from nuitka.utils.AppDirs import getCacheDir
 from nuitka.utils.FileOperations import listDir, removeDirectory
 from nuitka.utils.Importing import getSharedLibrarySuffixes
 from nuitka.utils.ModuleNames import ModuleName
+from nuitka.utils.SharedLibraries import (
+    hasUniversalOrMatchingMacOSArchitecture,
+)
 from nuitka.utils.Utils import isMacOS, isWin32OrPosixWindows
 
 from .IgnoreListing import isIgnoreListedNotExistingModule
@@ -64,22 +70,49 @@ _debug_module_finding = Options.shallExplainImports()
 warned_about = set()
 
 # Directory where the main script lives. Should attempt to import from there.
-main_path = None
+_main_paths = OrderedSet()
+
+# Additions to sys.paths from plugins.
+_extra_paths = OrderedSet()
+
+ModuleUsageAttempt = makeNamedtupleClass(
+    "ModuleUsageAttempt",
+    ("module_name", "filename", "module_kind", "finding", "level", "source_ref"),
+)
 
 
-def setMainScriptDirectory(main_dir):
+def makeModuleUsageAttempt(
+    module_name, filename, module_kind, finding, level, source_ref
+):
+    assert source_ref is not None
+
+    return ModuleUsageAttempt(
+        module_name=module_name,
+        filename=filename,
+        module_kind=module_kind,
+        finding=finding,
+        level=level,
+        source_ref=source_ref,
+    )
+
+
+def addMainScriptDirectory(main_dir):
     """Initialize the main script directory.
 
     We use this as part of the search path for modules.
     """
-    # We need to set this from the outside, pylint: disable=global-statement
-
-    global main_path
-    main_path = main_dir
+    _main_paths.add(main_dir)
 
 
-def getMainScriptDirectory():
-    return main_path
+def addExtraSysPaths(directories):
+    for directory in directories:
+        assert os.path.isdir(directory), directory
+
+        _extra_paths.add(directory)
+
+
+def hasMainScriptDirectory():
+    return bool(_main_paths)
 
 
 def isPackageDir(dirname):
@@ -115,30 +148,26 @@ def getModuleNameAndKindFromFilename(module_filename):
         by the using code. It cannot be decided from the filename at all.
     """
 
-    # TODO: This does not handle ".pyw" files it seems.
+    if module_filename.endswith(".py"):
+        return ModuleName(os.path.basename(module_filename)[:-3]), "py"
+
+    for suffix in getSharedLibrarySuffixes():
+        if module_filename.endswith(suffix):
+            return (
+                ModuleName(os.path.basename(module_filename)[: -len(suffix)]),
+                "extension",
+            )
+
     if os.path.isdir(module_filename):
-        module_name = ModuleName(os.path.basename(module_filename))
-        module_kind = "py"
-    elif module_filename.endswith(".py"):
-        module_name = ModuleName(os.path.basename(module_filename)[:-3])
-        module_kind = "py"
-    else:
-        for suffix in getSharedLibrarySuffixes():
-            if module_filename.endswith(suffix):
-                module_name = ModuleName(
-                    os.path.basename(module_filename)[: -len(suffix)]
-                )
-                module_kind = "extension"
+        return ModuleName(os.path.basename(module_filename)), "py"
 
-                break
-        else:
-            module_kind = None
-            module_name = None
-
-    return module_name, module_kind
+    return None, None
 
 
 def isIgnoreListedImportMaker(source_ref):
+    if isNuitkaPython():
+        return True
+
     return StandardLibrary.isStandardLibraryPath(source_ref.getFilename())
 
 
@@ -233,7 +262,7 @@ def findModule(module_name, parent_package, level):
         if parent_package is not None:
             parent_package = parent_package.getRelativePackageName(level)
         else:
-            return None, None, "not-found"
+            return None, None, None, "not-found"
 
     # Try relative imports first if we have a parent package.
     if level != 0 and parent_package is not None:
@@ -253,10 +282,10 @@ def findModule(module_name, parent_package, level):
             else:
                 module_filename = None
 
-            return full_name.getPackageName(), module_filename, "pth"
+            return full_name.getPackageName(), module_filename, "py", "pth"
 
         try:
-            module_filename = _findModule(module_name=full_name)
+            module_filename, module_kind = _findModule(module_name=full_name)
         except ImportError:
             # For relative import, that is OK, we will still try absolute.
             pass
@@ -267,7 +296,7 @@ def findModule(module_name, parent_package, level):
                     % (module_name, full_name, module_filename)
                 )
 
-            return full_name.getPackageName(), module_filename, "relative"
+            return full_name.getPackageName(), module_filename, module_kind, "relative"
 
     if level < 1 and module_name != "":
         module_name = normalizePackageName(module_name)
@@ -281,7 +310,7 @@ def findModule(module_name, parent_package, level):
                     "findModule: Absolute imported module '%s' in as built-in':"
                     % (module_name,)
                 )
-            return package_name, None, "built-in"
+            return package_name, None, None, "built-in"
 
         # Frozen module names are similar to built-in, but there is no list of
         # them, therefore check loader name. Not useful at this time
@@ -298,7 +327,7 @@ def findModule(module_name, parent_package, level):
                         "findModule: Absolute imported module '%s' in as frozen':"
                         % (module_name,)
                     )
-                return package_name, None, "built-in"
+                return package_name, None, None, "built-in"
 
         preloaded_path = getPreloadedPackagePath(module_name)
 
@@ -309,10 +338,10 @@ def findModule(module_name, parent_package, level):
             else:
                 module_filename = None
 
-            return package_name, module_filename, "pth"
+            return package_name, module_filename, "py", "pth"
 
         try:
-            module_filename = _findModule(module_name=module_name)
+            module_filename, module_kind = _findModule(module_name=module_name)
         except ImportError:
             # For relative import, that is OK, we will still try absolute.
             pass
@@ -323,16 +352,17 @@ def findModule(module_name, parent_package, level):
                     % (module_name, module_filename)
                 )
 
-            return package_name, module_filename, "absolute"
+            return package_name, module_filename, module_kind, "absolute"
 
-    return None, None, "not-found"
+    return None, None, None, "not-found"
 
 
 # Some platforms are case insensitive.
 case_sensitive = not isMacOS() and not isWin32OrPosixWindows()
 
 ImportScanFinding = collections.namedtuple(
-    "ImportScanFinding", ("found_in", "priority", "full_path", "search_order")
+    "ImportScanFinding",
+    ("found_in", "module_type", "priority", "full_path", "search_order"),
 )
 
 # We put here things that are not worth it (Cython is not really used by
@@ -368,6 +398,29 @@ existing '%s' extension module by default. Candidates were: %s <-> %s."""
                     )
 
 
+_list_dir_cache = {}
+
+
+def listDirCached(path):
+    """Cached listing of a directory."""
+
+    if path not in _list_dir_cache:
+        _list_dir_cache[path] = tuple(listDir(path))
+
+    return _list_dir_cache[path]
+
+
+def flushImportCache():
+    """Clear import related caches.
+
+    In some situations, e.g. during package rebuild, we scan and then decide to remove
+    files and scan again. This allows that. Nothing in standard Nuitka should do it,
+    as it throws away so much.
+    """
+    _list_dir_cache.clear()
+    module_search_cache.clear()
+
+
 def _findModuleInPath2(package_name, module_name, search_path):
     """This is out own module finding low level implementation.
 
@@ -417,6 +470,7 @@ def _findModuleInPath2(package_name, module_name, search_path):
                     candidates.add(
                         ImportScanFinding(
                             found_in=entry,
+                            module_type=module_type,
                             priority=priority_map[module_type],
                             full_path=package_directory,
                             search_order=count,
@@ -428,6 +482,7 @@ def _findModuleInPath2(package_name, module_name, search_path):
                 candidates.add(
                     ImportScanFinding(
                         found_in=entry,
+                        module_type=10,
                         priority=10,
                         full_path=package_directory,
                         search_order=count + len(search_path),
@@ -447,6 +502,7 @@ def _findModuleInPath2(package_name, module_name, search_path):
                 candidates.add(
                     ImportScanFinding(
                         found_in=entry,
+                        module_type=module_type,
                         priority=4 + priority_map[module_type],
                         full_path=full_path,
                         search_order=count,
@@ -457,36 +513,52 @@ def _findModuleInPath2(package_name, module_name, search_path):
     if _debug_module_finding:
         my_print("Candidates:", candidates)
 
+    found_candidate = None
+
     if candidates:
         # Sort by priority, with entries from same path element coming first, then desired type.
-        candidates = sorted(candidates, key=lambda c: (c.search_order, c.priority))
+        candidates = tuple(
+            sorted(candidates, key=lambda c: (c.search_order, c.priority))
+        )
 
         # On case sensitive systems, no resolution needed.
         if case_sensitive:
-            _reportCandidates(
-                package_name=package_name,
-                module_name=module_name,
-                candidate=candidates[0],
-                candidates=candidates,
-            )
-            return candidates[0].full_path
+            found_candidate = candidates[0]
         else:
             for candidate in candidates:
-                for fullname, _filename in listDir(candidate[0]):
+                for fullname, _filename in listDirCached(candidate.found_in):
                     if fullname == candidate.full_path:
-                        _reportCandidates(
-                            package_name=package_name,
-                            module_name=module_name,
-                            candidate=candidate,
-                            candidates=candidates,
-                        )
-                        return candidate.full_path
+                        found_candidate = candidate
+                        break
+
+                if found_candidate:
+                    break
 
             # Only exact case matches matter, all candidates were ignored,
             # lets just fall through to raising the import error.
 
-    # Nothing found.
-    raise ImportError
+    if found_candidate is None:
+        # Nothing found.
+        raise ImportError
+    if (
+        found_candidate.module_type == imp.C_EXTENSION
+        and isMacOS()
+        and not hasUniversalOrMatchingMacOSArchitecture(found_candidate.full_path)
+    ):
+        # Not usable for target architecture.
+        raise ImportError
+
+    _reportCandidates(
+        package_name=package_name,
+        module_name=module_name,
+        candidate=found_candidate,
+        candidates=candidates,
+    )
+
+    return (
+        found_candidate.full_path,
+        "extension" if found_candidate.module_type == imp.C_EXTENSION else "py",
+    )
 
 
 _egg_files = {}
@@ -521,12 +593,15 @@ def _unpackPathElement(path_entry):
 
 
 def getPackageSearchPath(package_name):
-    assert main_path is not None
+    assert _main_paths
 
     if package_name is None:
-        result = [os.getcwd(), main_path] + [
-            _unpackPathElement(path_element) for path_element in sys.path
-        ]
+        result = (
+            [os.getcwd()]
+            + list(_main_paths)
+            + [_unpackPathElement(path_element) for path_element in sys.path]
+            + list(_extra_paths)
+        )
     elif "." in package_name:
         parent_package_name, child_package_name = package_name.splitModuleBasename()
 
@@ -578,7 +653,7 @@ def _findModuleInPath(module_name):
         candidate = os.environ.get("NUITKA_SITE_FILENAME", "")
 
         if candidate:
-            return candidate
+            return candidate, "py"
 
     # Free pass for built-in modules, the need not exist.
     if package_name is None and imp.is_builtin(module_name):
@@ -592,7 +667,7 @@ def _findModuleInPath(module_name):
         )
 
     try:
-        module_filename = _findModuleInPath2(
+        module_filename, module_kind = _findModuleInPath2(
             package_name=package_name, module_name=module_name, search_path=search_path
         )
     except SyntaxError:
@@ -607,7 +682,7 @@ def _findModuleInPath(module_name):
     if _debug_module_finding:
         my_print("_findModuleInPath: _findModuleInPath2 gave", module_filename)
 
-    return module_filename
+    return module_filename, module_kind
 
 
 module_search_cache = {}
@@ -635,7 +710,11 @@ def _findModule(module_name):
 
         return result
 
-    module_search_cache[key] = _findModuleInPath(module_name)
+    try:
+        module_search_cache[key] = _findModuleInPath(module_name)
+    except ImportError:
+        module_search_cache[key] = ImportError
+        raise
 
     return module_search_cache[key]
 
@@ -651,12 +730,22 @@ def locateModule(module_name, parent_package, level):
         package containing it, and filename of it which can be a
         directory for packages, and the location method used.
     """
-    module_package, module_filename, finding = findModule(
+
+    if module_name.isMultidistModuleName():
+        return locateMultidistModule(module_name)
+
+    module_package, module_filename, module_kind, finding = findModule(
         module_name=module_name,
         parent_package=parent_package,
         level=level,
     )
 
+    # Allowing ourselves to be lazy.
+    if module_filename is None:
+        module_kind = None
+    else:
+        assert module_kind is not None, module_filename
+
     assert module_package is None or (
         type(module_package) is ModuleName and module_package != ""
     ), repr(module_package)
@@ -665,12 +754,19 @@ def locateModule(module_name, parent_package, level):
         module_filename = os.path.normpath(module_filename)
 
         module_name, module_kind = getModuleNameAndKindFromFilename(module_filename)
-
-        assert module_kind is not None, module_filename
-
         module_name = ModuleName.makeModuleNameInPackage(module_name, module_package)
+    elif finding == "not-found":
+        if parent_package is not None:
+            if not module_name:
+                module_name = parent_package
+            else:
+                module_name = ModuleName.makeModuleNameInPackage(
+                    package_name=parent_package, module_name=module_name
+                )
+        elif level > 0:
+            module_name = ModuleName("")
 
-    return module_name, module_filename, finding
+    return module_name, module_filename, module_kind, finding
 
 
 def locateModules(package_name):
