@@ -78,6 +78,11 @@ class ExpressionCall(ExpressionCallMixin, ChildrenExpressionCallMixin, Expressio
 
         return args.extractSideEffects() + kwargs.extractSideEffects()
 
+    def onContentEscapes(self, trace_collection):
+        self.subnode_called.onContentEscapes(trace_collection)
+        self.subnode_args.onContentEscapes(trace_collection)
+        self.subnode_kwargs.onContentEscapes(trace_collection)
+
 
 class ExpressionCallNoKeywords(
     ExpressionCallMixin, ChildrenExpressionCallNoKeywordsMixin, ExpressionBase
@@ -112,6 +117,10 @@ class ExpressionCallNoKeywords(
 
         return args.extractSideEffects()
 
+    def onContentEscapes(self, trace_collection):
+        self.subnode_called.onContentEscapes(trace_collection)
+        self.subnode_args.onContentEscapes(trace_collection)
+
 
 class ExpressionCallKeywordsOnly(
     ExpressionCallMixin, ChildrenExpressionCallKeywordsOnlyMixin, ExpressionBase
@@ -146,6 +155,10 @@ class ExpressionCallKeywordsOnly(
 
         return kwargs.extractSideEffects()
 
+    def onContentEscapes(self, trace_collection):
+        self.subnode_called.onContentEscapes(trace_collection)
+        self.subnode_kwargs.onContentEscapes(trace_collection)
+
 
 class ExpressionCallEmpty(
     ExpressionCallMixin, ChildrenExpressionCallEmptyMixin, ExpressionBase
@@ -176,6 +189,9 @@ class ExpressionCallEmpty(
     def extractSideEffectsPreCall():
         return ()
 
+    def onContentEscapes(self, trace_collection):
+        self.subnode_called.onContentEscapes(trace_collection)
+
 
 def makeExpressionCall(called, args, kw, source_ref):
     """Make the most simple call node possible.
