@@ -23,19 +23,21 @@ The classes are are at the core of the language and have their complexities.
 
 from nuitka.PythonVersions import python_version
 
-from .ExpressionBases import ExpressionChildrenHavingBase
+from .ChildrenHavingMixins import (
+    ChildrenExpressionBuiltinType3Mixin,
+    ChildrenHavingMetaclassBasesMixin,
+)
+from .ExpressionBases import ExpressionBase
+from .ExpressionShapeMixins import ExpressionDictShapeExactMixin
 from .IndicatorMixins import MarkNeedsAnnotationsMixin
 from .LocalsScopes import getLocalsDictHandle
 from .OutlineNodes import ExpressionOutlineFunctionBase
 
 
-class ExpressionClassBody(MarkNeedsAnnotationsMixin, ExpressionOutlineFunctionBase):
+class ExpressionClassBodyBase(ExpressionOutlineFunctionBase):
     kind = "EXPRESSION_CLASS_BODY"
 
-    __slots__ = ("needs_annotations_dict", "doc")
-
-    if python_version >= 0x340:
-        __slots__ += ("qualname_setup",)
+    __slots__ = ("doc",)
 
     def __init__(self, provider, name, doc, source_ref):
         ExpressionOutlineFunctionBase.__init__(
@@ -47,24 +49,17 @@ class ExpressionClassBody(MarkNeedsAnnotationsMixin, ExpressionOutlineFunctionBa
             source_ref=source_ref,
         )
 
-        MarkNeedsAnnotationsMixin.__init__(self)
-
         self.doc = doc
 
-        # Force creation with proper type.
-        if python_version >= 0x300:
-            locals_kind = "python3_class"
-        else:
-            locals_kind = "python2_class"
-
         self.locals_scope = getLocalsDictHandle(
             "locals_%s_%d" % (self.getCodeName(), source_ref.getLineNumber()),
-            locals_kind,
+            self.locals_kind,
             self,
         )
 
-        if python_version >= 0x340:
-            self.qualname_setup = None
+    @staticmethod
+    def isExpressionClassBodyBase():
+        return True
 
     def getDetails(self):
         return {
@@ -115,9 +110,13 @@ class ExpressionClassBody(MarkNeedsAnnotationsMixin, ExpressionOutlineFunctionBa
             self.taken.add(result)
             return result
 
-    def markAsDirectlyCalled(self):
+    @staticmethod
+    def markAsDirectlyCalled():
         pass
 
+    def getChildQualname(self, function_name):
+        return self.getFunctionQualname() + "." + function_name
+
     @staticmethod
     def mayHaveSideEffects():
         # The function definition has no side effects, calculating the defaults
@@ -132,36 +131,97 @@ class ExpressionClassBody(MarkNeedsAnnotationsMixin, ExpressionOutlineFunctionBa
         return True
 
 
-class ExpressionSelectMetaclass(ExpressionChildrenHavingBase):
+# TODO: Have a variation that knows dict shape or not statically.
+class ExpressionClassBodyP3(MarkNeedsAnnotationsMixin, ExpressionClassBodyBase):
+    kind = "EXPRESSION_CLASS_BODY_P3"
+
+    __slots__ = ("needs_annotations_dict",)
+
+    if python_version >= 0x340:
+        __slots__ += ("qualname_setup",)
+
+    # Force creation with proper type.
+    locals_kind = "python3_class"
+
+    def __init__(self, provider, name, doc, source_ref):
+        ExpressionClassBodyBase.__init__(
+            self,
+            provider=provider,
+            name=name,
+            doc=doc,
+            source_ref=source_ref,
+        )
+
+        MarkNeedsAnnotationsMixin.__init__(self)
+
+        if python_version >= 0x340:
+            self.qualname_setup = None
+
+
+class ExpressionClassBodyP2(ExpressionDictShapeExactMixin, ExpressionClassBodyBase):
+    kind = "EXPRESSION_CLASS_BODY_P2"
+
+    __slots__ = ()
+
+    locals_kind = "python2_class"
+
+    def __init__(self, provider, name, doc, source_ref):
+        ExpressionClassBodyBase.__init__(
+            self,
+            provider=provider,
+            name=name,
+            doc=doc,
+            source_ref=source_ref,
+        )
+
+
+class ExpressionSelectMetaclass(ChildrenHavingMetaclassBasesMixin, ExpressionBase):
     kind = "EXPRESSION_SELECT_METACLASS"
 
     named_children = ("metaclass", "bases")
 
     def __init__(self, metaclass, bases, source_ref):
-        ExpressionChildrenHavingBase.__init__(
-            self, values={"metaclass": metaclass, "bases": bases}, source_ref=source_ref
+        ChildrenHavingMetaclassBasesMixin.__init__(
+            self,
+            metaclass=metaclass,
+            bases=bases,
         )
 
+        ExpressionBase.__init__(self, source_ref)
+
     def computeExpression(self, trace_collection):
+        if self.subnode_bases.isExpressionConstantTupleEmptyRef():
+            return (
+                self.subnode_metaclass,
+                "new_expression",
+                "Metaclass selection without bases is trivial.",
+            )
+
         # TODO: Meta class selection is very computable, and should be done, but we need
         # dictionary tracing for that.
         trace_collection.onExceptionRaiseExit(BaseException)
 
         return self, None, None
 
+    def mayRaiseException(self, exception_type):
+        return not self.subnode_bases.isExpressionConstantTupleEmptyRef()
 
-class ExpressionBuiltinType3(ExpressionChildrenHavingBase):
+
+class ExpressionBuiltinType3(ChildrenExpressionBuiltinType3Mixin, ExpressionBase):
     kind = "EXPRESSION_BUILTIN_TYPE3"
 
-    named_children = ("type_name", "bases", "dict")
+    named_children = ("type_name", "bases", "dict_arg")
 
-    def __init__(self, type_name, bases, type_dict, source_ref):
-        ExpressionChildrenHavingBase.__init__(
+    def __init__(self, type_name, bases, dict_arg, source_ref):
+        ChildrenExpressionBuiltinType3Mixin.__init__(
             self,
-            values={"type_name": type_name, "bases": bases, "dict": type_dict},
-            source_ref=source_ref,
+            type_name=type_name,
+            bases=bases,
+            dict_arg=dict_arg,
         )
 
+        ExpressionBase.__init__(self, source_ref)
+
     def _calculateMetaClass(self):
         # TODO: Share code with ExpressionSelectMetaclass
 
@@ -174,10 +234,10 @@ class ExpressionBuiltinType3(ExpressionChildrenHavingBase):
         # Need to use private CPython API unless we want to re-implement it, pylint: disable=protected-access
         import ctypes
 
-        ctypes.pythonapi._PyType_CalculateMetaclass.argtypes = [
+        ctypes.pythonapi._PyType_CalculateMetaclass.argtypes = (
             ctypes.py_object,
             ctypes.py_object,
-        ]
+        )
         ctypes.pythonapi._PyType_CalculateMetaclass.restype = ctypes.py_object
 
         bases = self.subnode_bases.getCompileTimeConstant()
