@@ -208,12 +208,29 @@ module_typing_trust = {
     "TYPE_CHECKING": trust_constant,
 }
 
-module_os_trust = {"name": trust_constant}
+module_os_trust = {
+    "name": trust_constant,
+    "listdir": trust_node,
+    "curdir": trust_constant,
+    "pardir": trust_constant,
+    "sep": trust_constant,
+    "extsep": trust_constant,
+    "altsep": trust_constant,
+    "pathsep": trust_constant,
+    "linesep": trust_constant,
+}
 
-module_os_path_trust = {"exists": trust_node, "isfile": trust_node, "isdir": trust_node}
+module_os_path_trust = {
+    "exists": trust_node,
+    "isfile": trust_node,
+    "isdir": trust_node,
+    "basename": trust_node,
+}
 
 
-module_ctypes_trust = {"CDLL": trust_node}
+module_ctypes_trust = {
+    "CDLL": trust_node,
+}
 
 # module_platform_trust = {"python_implementation": trust_function}
 
@@ -294,7 +311,12 @@ def _checkHardModules():
 
         for attribute_name, trust_value in trust.items():
             if trust_value is trust_node:
-                assert (module_name, attribute_name) in trust_node_factory, (
+                assert (
+                    module_name,
+                    attribute_name,
+                ) in trust_node_factory or os.path.basename(sys.argv[0]).startswith(
+                    "generate-"
+                ), (
                     module_name,
                     attribute_name,
                 )
@@ -447,8 +469,8 @@ class ExpressionImportModuleFixed(ExpressionBase):
         else:
             return tshape_module
 
-    def getUsedModules(self):
-        yield makeModuleUsageAttempt(
+    def getModuleUsageAttempt(self):
+        return makeModuleUsageAttempt(
             module_name=self.found_module_name,
             filename=self.found_module_filename,
             finding=self.finding,
@@ -547,6 +569,9 @@ class ExpressionImportModuleHard(
         if self.mayRaiseException(BaseException):
             trace_collection.onExceptionRaiseExit(BaseException)
 
+        # Trace the module usage attempt.
+        trace_collection.onModuleUsageAttempt(self.getModulesUsageAttempt())
+
         return self, None, None
 
     def computeExpressionImportName(self, import_node, import_name, trace_collection):
@@ -1068,9 +1093,6 @@ class ExpressionBuiltinImport(ChildrenExpressionBuiltinImportMixin, ExpressionBa
 
             return None
 
-    def getUsedModules(self):
-        return self.used_modules
-
     def computeExpression(self, trace_collection):
         # Attempt to recurse if not already done, many cases to consider
         # pylint: disable=too-many-branches
@@ -1082,6 +1104,10 @@ class ExpressionBuiltinImport(ChildrenExpressionBuiltinImportMixin, ExpressionBa
                 # If we know it exists, only RuntimeError shall occur.
                 trace_collection.onExceptionRaiseExit(RuntimeError)
 
+            # Trace the module usage attempts.
+            for module_usage_attempt in self.used_modules:
+                trace_collection.onModuleUsageAttempt(module_usage_attempt)
+
             # We stay here.
             return self, None, None
 
@@ -1096,9 +1122,12 @@ class ExpressionBuiltinImport(ChildrenExpressionBuiltinImportMixin, ExpressionBa
             imported_module_name = module_name.getCompileTimeConstant()
 
             module_filename = self._attemptFollow(module_name=imported_module_name)
-
             self.follow_attempted = True
 
+            # Trace the module usage attempts.
+            for module_usage_attempt in self.used_modules:
+                trace_collection.onModuleUsageAttempt(module_usage_attempt)
+
             if type(imported_module_name) in (str, unicode):
                 imported_module_name = resolveModuleName(imported_module_name)
 
@@ -1191,6 +1220,11 @@ class ExpressionBuiltinImport(ChildrenExpressionBuiltinImportMixin, ExpressionBa
 
                 return new_node, change_tags, message
 
+        # Trace the module usage attempts, doing it twice will not harm, this
+        # becomes a set.
+        for module_usage_attempt in self.used_modules:
+            trace_collection.onModuleUsageAttempt(module_usage_attempt)
+
         # TODO: May return a module or module variable reference of some sort in
         # the future with embedded modules.
         return self, None, None
