@@ -53,7 +53,7 @@ def _checkBases(name, bases):
 class NodeCheckMetaClass(ABCMeta):
     kinds = {}
 
-    def __new__(cls, name, bases, dictionary):  # pylint: disable=I0021,arguments-differ
+    def __new__(mcs, name, bases, dictionary):  # pylint: disable=I0021,arguments-differ
         _checkBases(name, bases)
 
         if "__slots__" not in dictionary:
@@ -86,7 +86,10 @@ class NodeCheckMetaClass(ABCMeta):
         ), dictionary["__slots__"]
 
         if "python_version_spec" in dictionary:
-            condition = "%s %s" % (python_version, dictionary["python_version_spec"])
+            condition = "%s %s" % (
+                hex(python_version),
+                dictionary["python_version_spec"],
+            )
 
             # We trust our node class files, pylint: disable=eval-used
             if not eval(condition):
@@ -100,8 +103,7 @@ class NodeCheckMetaClass(ABCMeta):
         if "checker" in dictionary:
             dictionary["checker"] = staticmethod(dictionary["checker"])
 
-        # false alarm, pylint: disable=I0021,too-many-function-args
-        return ABCMeta.__new__(cls, name, bases, dictionary)
+        return ABCMeta.__new__(mcs, name, bases, dictionary)
 
     def __init__(cls, name, bases, dictionary):
 
