@@ -1,4 +1,4 @@
-#     Copyright 2021, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2022, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -26,7 +26,7 @@ class NuitkaPluginKivy(NuitkaPluginBase):
     """This class represents the main logic of the plugin."""
 
     plugin_name = "kivy"
-    plugin_desc = "Required by kivy package"
+    plugin_desc = "Required by 'kivy' package."
 
     @staticmethod
     def isAlwaysEnabled():
@@ -130,6 +130,7 @@ except ImportError:
                     source_path=full_path,
                     dest_path=target_filename,
                     package_name=full_name,
+                    reason="needed by 'kivy'",
                 )
 
             self.reportFileCount(full_name, len(kivy_dlls))
