@@ -1,4 +1,4 @@
-#     Copyright 2021, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2022, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Part of "Nuitka", an optimizing Python compiler that is compatible and
 #     integrates with CPython, but also works on its own.
@@ -37,7 +37,7 @@ class NuitkaPluginUpx(NuitkaPluginBase):
     """
 
     plugin_name = "upx"  # Nuitka knows us by this name
-    plugin_desc = "Compress created binaries with UPX automatically"
+    plugin_desc = "Compress created binaries with UPX automatically."
 
     def __init__(self, upx_path, upx_nocache):
         self.upx_binary = getExecutablePath("upx", upx_path)
