@@ -20,9 +20,7 @@
 import os
 import sys
 
-from nuitka.__past__ import (  # pylint: disable=I0021,redefined-builtin
-    WindowsError,
-)
+from nuitka.__past__ import WindowsError  # pylint: disable=I0021,redefined-builtin
 from nuitka.containers.OrderedSets import OrderedSet
 from nuitka.PythonVersions import python_version_str
 
@@ -50,7 +48,7 @@ class InstalledPython(object):
         return self.python_exe
 
     def getPythonVersion(self):
-        return "%d.%d" % (self.python_version // 256, (self.python_version // 16) % 16)
+        return self.python_version
 
     # Necessary for Python 2.7, otherwise SyntaxError is given on exec.
     @staticmethod
@@ -116,6 +114,38 @@ class InstalledPython(object):
 _installed_pythons = {}
 
 
+def getInstalledPythonRegistryPaths(python_version):
+    """Yield all Pythons as found in the Windows registry."""
+    # Windows only code, pylint: disable=I0021,import-error,undefined-variable
+    if str is bytes:
+        import _winreg as winreg  # pylint: disable=I0021,import-error,no-name-in-module
+    else:
+        import winreg  # pylint: disable=I0021,import-error,no-name-in-module
+
+    for hkey_branch in (winreg.HKEY_LOCAL_MACHINE, winreg.HKEY_CURRENT_USER):
+        for arch_key in (0, winreg.KEY_WOW64_32KEY, winreg.KEY_WOW64_64KEY):
+            for suffix in "", "-32", "-arm64":
+                try:
+                    key = winreg.OpenKey(
+                        hkey_branch,
+                        r"SOFTWARE\Python\PythonCore\%s%s\InstallPath"
+                        % (python_version, suffix),
+                        0,
+                        winreg.KEY_READ | arch_key,
+                    )
+
+                    install_dir = os.path.normpath(winreg.QueryValue(key, ""))
+                except WindowsError:
+                    pass
+                else:
+                    candidate = os.path.normpath(
+                        os.path.join(install_dir, "python.exe")
+                    )
+
+                    if os.path.exists(candidate):
+                        yield candidate
+
+
 def _getPythonInstallPathsWindows(python_version):
     """Find Python installation on Windows.
 
@@ -141,35 +171,10 @@ def _getPythonInstallPathsWindows(python_version):
 
         seen.add(candidate)
 
-    # Windows only code, pylint: disable=I0021,import-error,undefined-variable
-    if str is bytes:
-        import _winreg as winreg  # pylint: disable=I0021,import-error,no-name-in-module
-    else:
-        import winreg  # pylint: disable=I0021,import-error,no-name-in-module
-
-    for hkey_branch in (winreg.HKEY_LOCAL_MACHINE, winreg.HKEY_CURRENT_USER):
-        for arch_key in (0, winreg.KEY_WOW64_32KEY, winreg.KEY_WOW64_64KEY):
-            for suffix in "", "-32":
-                try:
-                    key = winreg.OpenKey(
-                        hkey_branch,
-                        r"SOFTWARE\Python\PythonCore\%s%s\InstallPath"
-                        % (python_version, suffix),
-                        0,
-                        winreg.KEY_READ | arch_key,
-                    )
-
-                    install_dir = os.path.normpath(winreg.QueryValue(key, ""))
-                except WindowsError:
-                    pass
-                else:
-                    candidate = os.path.normpath(
-                        os.path.join(install_dir, "python.exe")
-                    )
-
-                    if os.path.exists(candidate) and candidate not in seen:
-                        yield candidate
-                        seen.add(candidate)
+    for candidate in getInstalledPythonRegistryPaths(python_version=python_version):
+        if candidate not in seen:
+            seen.add(candidate)
+            yield candidate
 
 
 def findPythons(python_version):
