@@ -1,4 +1,4 @@
-#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2022, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Python tests originally created or extracted from other peoples work. The
 #     parts were too small to be protected.
@@ -17,6 +17,9 @@
 #
 from __future__ import print_function
 
+import sys
+
+
 def displayDict(d):
     d = dict(d)
 
@@ -25,7 +28,10 @@ def displayDict(d):
     del d["__builtins__"]
 
     if "__loader__" in d:
-        d["__loader__"] = "<__loader__ removed>"
+        if str is bytes:
+            del d["__loader__"]
+        else:
+            d["__loader__"] = "<__loader__ removed>"
 
     if "__file__" in d:
         d["__file__"] = "<__file__ removed>"
@@ -42,6 +48,7 @@ def displayDict(d):
         del d["__compiled__"]
 
     import pprint
+
     return pprint.pformat(d)
 
 
@@ -49,10 +56,9 @@ print(displayDict(globals()))
 
 print("__name__: ", __name__)
 
-import sys
 print(
     "__package__: ",
     __package__
-      if __package__ is not None or sys.version_info[:2] != (3,2) else
-    ".".join(__name__.split(".")[:-1])
+    if __package__ is not None or sys.version_info[:2] != (3, 2)
+    else ".".join(__name__.split(".")[:-1]),
 )
