@@ -1,4 +1,4 @@
-#     Copyright 2019, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2022, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Python tests originally created or extracted from other peoples work. The
 #     parts were too small to be protected.
@@ -19,4 +19,4 @@ import pyexpat
 
 print("Imported pyexpat, should use our one.")
 
-print([x for x in dir(pyexpat) if x != "__compiled__"])
+print([x for x in dir(pyexpat) if x not in ("__compiled__", "__loader__")])
