@@ -1,4 +1,4 @@
-#     Copyright 2020, Kay Hayen, mailto:kay.hayen@gmail.com
+#     Copyright 2022, Kay Hayen, mailto:kay.hayen@gmail.com
 #
 #     Python tests originally created or extracted from other peoples work. The
 #     parts were too small to be protected.
@@ -17,6 +17,6 @@
 #
 
 try:
-    from sys import not_there, *
+    from sys import not_there, * # isort:skip
 except Exception as e:
     print( "Star import with extra stuff not present gave", e )
