@@ -15,4 +15,4 @@
 #     See the License for the specific language governing permissions and
 #     limitations under the License.
 #
-foo, *bar, baz, *a, b = name.split('/')
+foo, *bar, baz, *a, b = name.split("/")
